==> rendition-14.9.0.tgz: package/dist_esm5/components/Modal/index.js <==
import { __assign, __extends, __makeTemplateObject, __rest } from "tslib";
import { Layer } from 'grommet';
import assign from 'lodash/assign';
import * as React from 'react';
import styled, { createGlobalStyle, withTheme } from 'styled-components';
import { px } from '../../utils';
import { Box } from '../Box';
import Button from '../Button';
import { Flex } from '../Flex';
import Heading from '../Heading';
import Txt from '../Txt';
var bodyNoOverflowClass = "rendition-modal-open";
var GlobalStyle = createGlobalStyle(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t.", " {\n\t\toverflow: hidden;\n\t}\n"], ["\n\t.", " {\n\t\toverflow: hidden;\n\t}\n"])), bodyNoOverflowClass);
var DEFAULT_MODAL_WIDTH = 700;
var ModalSizer = styled(Box)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\toverflow-y: auto;\n"], ["\n\toverflow-y: auto;\n"])));
var HeadingDescription = styled(Txt)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tfont-weight: normal;\n"], ["\n\tfont-weight: normal;\n"])));
var ModalButton = function (props) {
    return 'href' in props && props.href ? (React.createElement(Button, __assign({ as: "a" }, props))) : (React.createElement(Button, __assign({}, props)));
};
var Modal = (function (_super) {
    __extends(Modal, _super);
    function Modal(props) {
        var _this = _super.call(this, props) || this;
        _this.ownIndex = 0;
        _this.handleKeyDown = function (e) {
            var _a;
            if (Modal.mountedCount !== _this.ownIndex) {
                return;
            }
            if (!e.defaultPrevented && e.which === 13) {
                e.preventDefault();
                e.stopPropagation();
                if ((_a = _this.props.primaryButtonProps) === null || _a === void 0 ? void 0 : _a.disabled) {
                    return;
                }
                if (e.which === 13) {
                    _this.props.done();
                }
            }
        };
        _this.stopPropagation = function (e) {
            return e.stopPropagation();
        };
        _this.popModal = function () {
            if (Modal.mountedCount !== _this.ownIndex) {
                return;
            }
            (_this.props.cancel || _this.props.done)();
        };
        return _this;
    }
    Modal.prototype.componentDidMount = function () {
        if (!Modal.mountedCount) {
            document.body.classList.add(bodyNoOverflowClass);
        }
        window.document.addEventListener('keydown', this.handleKeyDown);
        Modal.mountedCount++;
        this.ownIndex = Modal.mountedCount;
    };
    Modal.prototype.componentWillUnmount = function () {
        Modal.mountedCount--;
        if (!Modal.mountedCount) {
            document.body.classList.remove(bodyNoOverflowClass);
        }
        window.document.removeEventListener('keydown', this.handleKeyDown);
    };
    Modal.prototype.render = function () {
        var _a = this.props, width = _a.width, theme = _a.theme, props = __rest(_a, ["width", "theme"]);
        var cancelButtonProps = assign({ style: { marginRight: 20 } }, props.cancelButtonProps);
        var secondaryButtonProps = assign({
            primary: true,
            outline: true,
            style: { marginRight: 20 },
        }, props.secondaryButtonProps);
        var primaryButtonProps = assign({ primary: true }, props.primaryButtonProps);
        return (React.createElement(Layer, { onEsc: this.popModal, onClickOutside: this.popModal, responsive: false, margin: "small", animate: false },
            React.createElement(GlobalStyle, null),
            React.createElement(ModalSizer, { p: [px(theme.space[3]), '40px 50px 30px'], width: width || DEFAULT_MODAL_WIDTH, maxWidth: "100%", onClick: this.stopPropagation, style: props.style, id: props.id, className: props.className },
                props.titleElement ? (React.createElement(Heading.h3, { mb: 50 }, props.titleElement)) : (!!props.title && (React.createElement(Heading.h3, { mb: 50 },
                    props.title,
                    !!props.titleDetails && (React.createElement(HeadingDescription, { color: "text.light", fontSize: 2 }, props.titleDetails))))),
                props.children,
                React.createElement(Flex, { mt: 50, alignItems: "center", justifyContent: "flex-end" },
                    props.cancel && (React.createElement(ModalButton, __assign({}, cancelButtonProps, { onClick: props.cancel }), (cancelButtonProps && cancelButtonProps.children) || 'Cancel')),
                    props.secondaryButtonProps && (React.createElement(ModalButton, __assign({}, secondaryButtonProps))),
                    React.createElement(ModalButton, __assign({}, primaryButtonProps, { onClick: props.done }), props.action || 'OK')))));
    };
    Modal.mountedCount = 0;
    return Modal;
}(React.Component));
export default withTheme(Modal);
var templateObject_1, templateObject_2, templateObject_3;

==> rendition-14.11.1.tgz: package/dist_esm5/components/Modal/index.js <==
import { __assign, __extends, __makeTemplateObject, __rest } from "tslib";
import { Layer } from 'grommet';
import assign from 'lodash/assign';
import * as React from 'react';
import styled, { createGlobalStyle, withTheme } from 'styled-components';
import { px } from '../../utils';
import { Box } from '../Box';
import Button from '../Button';
import { Flex } from '../Flex';
import Heading from '../Heading';
import Txt from '../Txt';
var bodyNoOverflowClass = "rendition-modal-open";
var GlobalStyle = createGlobalStyle(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t.", " {\n\t\toverflow: hidden;\n\t}\n"], ["\n\t.", " {\n\t\toverflow: hidden;\n\t}\n"])), bodyNoOverflowClass);
var DEFAULT_MODAL_WIDTH = 700;
var ModalSizer = styled(Box)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\toverflow-y: auto;\n"], ["\n\toverflow-y: auto;\n"])));
var HeadingDescription = styled(Txt)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tfont-weight: normal;\n"], ["\n\tfont-weight: normal;\n"])));
var ModalButton = function (props) {
    return 'href' in props && props.href ? (React.createElement(Button, __assign({ as: "a" }, props))) : (React.createElement(Button, __assign({}, props)));
};
var Modal = (function (_super) {
    __extends(Modal, _super);
    function Modal(props) {
        var _this = _super.call(this, props) || this;
        _this.ownIndex = 0;
        _this.handleKeyDown = function (e) {
            var _a;
            if (Modal.mountedCount !== _this.ownIndex) {
                return;
            }
            if (!e.defaultPrevented && e.which === 13) {
                e.preventDefault();
                e.stopPropagation();
                if ((_a = _this.props.primaryButtonProps) === null || _a === void 0 ? void 0 : _a.disabled) {
                    return;
                }
                if (e.which === 13) {
                    _this.props.done();
                }
            }
        };
        _this.stopPropagation = function (e) {
            return e.stopPropagation();
        };
        _this.popModal = function () {
            if (Modal.mountedCount !== _this.ownIndex) {
                return;
            }
            (_this.props.cancel || _this.props.done)();
        };
        return _this;
    }
    Modal.prototype.componentDidMount = function () {
        if (!Modal.mountedCount) {
            document.body.classList.add(bodyNoOverflowClass);
        }
        window.document.addEventListener('keydown', this.handleKeyDown);
        Modal.mountedCount++;
        this.ownIndex = Modal.mountedCount;
    };
    Modal.prototype.componentWillUnmount = function () {
        Modal.mountedCount--;
        if (!Modal.mountedCount) {
            document.body.classList.remove(bodyNoOverflowClass);
        }
        window.document.removeEventListener('keydown', this.handleKeyDown);
    };
    Modal.prototype.render = function () {
        var _a = this.props, width = _a.width, theme = _a.theme, props = __rest(_a, ["width", "theme"]);
        var cancelButtonProps = assign({ style: { marginRight: 20 } }, props.cancelButtonProps);
        var secondaryButtonProps = assign({
            primary: true,
            outline: true,
            style: { marginRight: 20 },
        }, props.secondaryButtonProps);
        var primaryButtonProps = assign({ primary: true }, props.primaryButtonProps);
        return (React.createElement(Layer, { onEsc: this.popModal, onClickOutside: this.popModal, responsive: false, margin: "small", animate: false },
            React.createElement(GlobalStyle, null),
            React.createElement(ModalSizer, { width: width || DEFAULT_MODAL_WIDTH, maxWidth: "100%", onClick: this.stopPropagation, style: props.style, id: props.id, className: props.className },
                React.createElement(Box, { p: [px(theme.space[3]), '40px 50px 30px'] },
                    props.titleElement ? (React.createElement(Heading.h3, { mb: 50 }, props.titleElement)) : (!!props.title && (React.createElement(Heading.h3, { mb: 50 },
                        props.title,
                        !!props.titleDetails && (React.createElement(HeadingDescription, { color: "text.light", fontSize: 2 }, props.titleDetails))))),
                    props.children,
                    React.createElement(Flex, { mt: 50, alignItems: "center", justifyContent: "flex-end" },
                        props.cancel && (React.createElement(ModalButton, __assign({}, cancelButtonProps, { onClick: props.cancel }), (cancelButtonProps && cancelButtonProps.children) ||
                            'Cancel')),
                        props.secondaryButtonProps && (React.createElement(ModalButton, __assign({}, secondaryButtonProps))),
                        React.createElement(ModalButton, __assign({}, primaryButtonProps, { onClick: props.done }), props.action || 'OK'))))));
    };
    Modal.mountedCount = 0;
    return Modal;
}(React.Component));
export default withTheme(Modal);
var templateObject_1, templateObject_2, templateObject_3;
